@@ -15,9 +15,9 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
-#ifndef _FILL_H
+#ifndef FILL_H
 
-#define _FILL_H 1
+#define FILL_H 1
 
 #include "map.h"
 
