@@ -216,7 +216,8 @@ main (argc, argv)
 	{"curses", 0, 0, 'c'},
 #endif
 	{"help", 0, 0, 1000},
-	{"version", 0, 0, 1001}
+	{"version", 0, 0, 1001},
+	{0, 0, 0, 0}
       };
 
       c = getopt_long (argc, argv, "c",
@@ -231,11 +232,6 @@ main (argc, argv)
 	  use_curses = 1;
 	  break;
 #endif
-	case 'm':
-	  if (game_map.map == NULL)
-	    {
-	    }
-	  break;
 	case 1000:
 	default:
 	  help_msg ();
@@ -251,9 +247,7 @@ main (argc, argv)
 
   if (argc == optind)
     list_maps ();
-  status_msg = (char *) load_map (argv[optind++]);
-  if (status_msg)
-    die (status_msg);
+  load_map (argv[optind++]);
 
 #ifdef HAVE_LIBPTHREAD
 #ifdef HAVE_LIBCURSES
