@@ -107,7 +107,7 @@ free_map ()
   free (game_map.capital);
 }
 
-extern char *
+extern void
 load_map (map_dir)
      char *map_dir;
 {
@@ -136,7 +136,7 @@ load_map (map_dir)
   game_map.n_att=read_number (file, &status);
 
   if (status != 0)
-    return alloc_err_str (2, map_dir);
+    die ("invalid map file header: %s", map_dir);
 
   game_map.begin_turn = 1;
   game_map.players_left = game_map.players;
@@ -157,7 +157,7 @@ load_map (map_dir)
       if (c == EOF)
 	{
 	  free_map ();
-	  return alloc_err_str (2, map_dir);
+	  die ("unexpected EOF while reading map file: %s", map_dir);
 	}
       if (islower (c))
 	{
@@ -175,7 +175,7 @@ load_map (map_dir)
       else
 	{
 	  free_map ();
-	  return alloc_err_str (ERR_INVNAME, map_dir);
+	  die ("invalid map file: %s", map_dir);
 	}
 
       c = get_char (file);
@@ -195,14 +195,13 @@ load_map (map_dir)
       else if (c == EOF)
 	{
 	  free_map ();
-	  return alloc_err_str (2, map_dir);
+	  die ("unexpected EOF while reading map file: %s", map_dir);
 	}
     }
   fclose (file);
   game_map.bit_cross >>= 1;
   set_modes ();
   game_map.sel_mode = game_map.def_mode;
-  return (char *) NULL;
 }
 
 extern void
