@@ -429,6 +429,8 @@ action (action, act)
     case MODE_ATT:
       {
 	int i;
+	/* Make sure the selected mode isn't something it shouldn't be.  */
+	game_map.sel_mode = MODE_ATT;
 	if (++game_map.n_att == ATT_PER_TURN)
 	  act->type = EVENT_ATT | EVENT_NEWTURN;
 	else
