@@ -15,9 +15,9 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
-#ifndef _OCCUPY_H
+#ifndef OCCUPY_H
 
-#define _OCCUPY_H 1
+#define OCCUPY_H 1
 
 #define ATT_PER_TURN 6
 #define EVENT_ATT 1
