@@ -21,20 +21,7 @@
 
 #include <stdlib.h>
 
-/* TODO: This system is brain-damaged.  */
-enum motti_errors {
-  ERR_NONAME,		/* A map file wasn't found.  */
-  ERR_INVNAME,		/* Invalid map file.  */
-  ERR_NOX,		/* Can't open display.  */
-  ERR_NOFONT,		/* Can't load font.  */
-  ERR_MALLOC,		/* Can't alloc memory.  */
-  ERR_COLOR_FIND,	/* Can't find a color value.  */
-  ERR_COLOR_ALLOC,	/* Can't allocate a color value.  */
-  ERR_MOUSE		/* Invalid mouse action specified.  */
-};
-
 extern void die (const char *, ...);
-extern char *alloc_err_str (enum motti_errors, const char *);
 extern void *my_malloc (size_t);
 extern void *my_calloc (size_t, size_t);
 
