@@ -16,10 +16,12 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
 
-#ifndef _XEVENT_H
+#ifndef XEVENT_H
 
-#define _XEVENT_H 1
+#define XEVENT_H 1
 
-extern void event_loop (void);
+#include "xinit.h"
+
+extern void event_loop (struct x_info_struct *);
 
 #endif /* xevent.h */
