@@ -173,7 +173,7 @@ init_DB_tab (x_info)
 	      *((enum mouse_action *) val_ptr->ptr) =
 		parse_mouse_string (value.addr);
 	      if (*((enum mouse_action *) val_ptr->ptr) > no_act)
-		die (alloc_err_str (ERR_MOUSE, value.addr));
+		die ("invalid mouse action: %s", value.addr);
 	      break;
 	    }
 	}
@@ -209,7 +209,6 @@ create_DB (x_info)
 
   /* These are defined now for later use.  */
   x_info->screen_num = DefaultScreen (x_info->display);
-  x_info->colormap = DefaultColormap (x_info->display, x_info->screen_num);
   x_info->depth = DefaultDepth (x_info->display, x_info->screen_num);
 
   /* First get the application defaults.  */
@@ -265,17 +264,37 @@ alloc_Xrm_color (x_info, instance, class, deflt, color)
 		   deflt, instance);
 	}
       else
-	msg = alloc_err_str (ERR_COLOR_FIND, class);
+	{
+	  fprintf (stderr, "motti: can't find color: %s\n", class);
+	  return 0;
+	}
     }
 
-  if (!msg && !XAllocNamedColor (x_info->display, x_info->colormap,
-				 color_name, color, &nullcol))
-    msg = alloc_err_str (ERR_COLOR_ALLOC, color_name);
-  else
-    return 1;
-  fprintf (stderr, "motti: %s\n", msg);
-  free (msg);
-  return 0;
+  while (!XAllocNamedColor (x_info->display, x_info->colormap, color_name,
+			    color, &nullcol))
+    {
+      if (!x_info->own_colormap) /* Don't try to get another colormap.  */
+	{
+	  /* I've decided to use this function instead of displaying an error
+	     and exiting, since motti might have several connections open, and
+	     each one of them would then have to be told explicitly with a
+	     command line argument to create an own colormap.  */
+	  x_info->colormap = XCopyColormapAndFree (x_info->display,
+						   x_info->colormap);
+	  x_info->own_colormap = 1;	/* Now have own colormap.  */
+	  /* Let the user know we have taken the liberty to allocate a new
+	     colormap.  */
+	  fprintf (stderr, "motti: created a new colormap for display \"%s\"\n",
+		   x_info->display);
+	  continue;	/* Try again, with an own colormap.  */
+	}
+      else
+	{
+	  fprintf (stderr, "motti: can't allocate a color: %s\n", color_name);
+	  return 0;
+	}
+    }
+  return 1;
 }
 
 extern int
@@ -285,12 +304,17 @@ alloc_colors (x_info)
   int i;
   XVisualInfo visual_info;
 
-  /* Search for the best visual, use color if possible */
+  /* Search for the best visual.  */
   for (i = 5; !XMatchVisualInfo (x_info->display, x_info->screen_num,
 				 x_info->depth, i, &visual_info); i--);
+  /* Would anybody feel like volunteering to write some monochrome visual
+     stuff?  */
   if (i < StaticColor)
     return 0;
 
+  x_info->colormap = DefaultColormap (x_info->display, x_info->screen_num);
+  x_info->own_colormap = 0;
+
   x_info->player_col = (XColor *) my_malloc (sizeof(XColor)*game_map.players);
   x_info->occupied_col = (XColor *) my_malloc
     (sizeof(XColor)*game_map.players);
@@ -715,7 +739,7 @@ alloc_gcs (x_info)
   gcval.background = x_info->occupied_col[game_map.turn-1].pixel;
   gcval.font = XLoadFont (x_info->display, x_info->db_tab.cross_left_font);
   if (!gcval.font)
-    die (alloc_err_str (ERR_NOFONT, x_info->db_tab.cross_left_font));
+    die ("can't load font: %s", x_info->db_tab.cross_left_font);
   calculate_extents (x_info, gcval.font);
   x_info->turngc = XCreateGC (x_info->display, x_info->main_win, GCBackground
 			      | GCForeground | GCFont, &gcval);
@@ -736,7 +760,7 @@ set_hints (x_info, min_width, min_height, geom_specified)
 
   if (!XStringListToTextProperty (&window_name, 1, &window_name_prop)
       || !XStringListToTextProperty (&icon_name, 1, &icon_name_prop))
-    die (alloc_err_str(ERR_MALLOC, (char *) NULL));
+    die ("can't allocate memory");
 
   /* Allocate needed structures for properties */
   size_hints = XAllocSizeHints ();
@@ -773,7 +797,6 @@ set_hints (x_info, min_width, min_height, geom_specified)
   XFree (icon_name_prop.value);
 }
 
-/* TODO: Change this to make BW support. */
 extern void
 open_windows (x_info)
      struct x_info_struct *x_info;
@@ -805,12 +828,13 @@ open_windows (x_info)
     }
 
   win_attribs.background_pixel = x_info->misc_col[bg_col].pixel;
+  win_attribs.colormap = x_info->colormap;
   x_info->main_win = XCreateWindow (x_info->display,
 				    RootWindow(x_info->display,
 					       x_info->screen_num), x, y,
 				    width, height, 0, CopyFromParent,
-				    InputOutput, CopyFromParent, CWBackPixel,
-				    &win_attribs);
+				    InputOutput, CopyFromParent,
+				    CWBackPixel|CWColormap, &win_attribs);
 
   alloc_gcs (x_info);
   make_att_pixs (x_info);
