@@ -67,13 +67,15 @@ struct x_info_struct {
   int main_win_width, main_win_height;
 
   Display *display;
-  /* This one is used to send events to other connections.  */
+  /* This one is used by other connections to send events.  */
   Display *common_display;
   int screen_num;
   Colormap colormap;
   int depth;
   XrmDatabase DB;
 
+  /* This one is true, if using an own colormap.  */
+  char own_colormap;
   XColor *player_col;
   XColor *occupied_col;
   XColor misc_col[last_col_num];
