@@ -320,7 +320,7 @@ create_end_win (x_info)
   gcvalues.font = XLoadFont (x_info->display, x_info->db_tab.end_font);
 
   if (!gcvalues.font)
-    die (alloc_err_str (ERR_NOFONT, x_info->db_tab.cross_left_font));
+    die ("can't load font: %s", x_info->db_tab.cross_left_font);
   x_info->endgamegc = XCreateGC (x_info->display, x_info->main_win,
 				 GCBackground | GCForeground | GCFont,
 				 &gcvalues);
