@@ -15,23 +15,26 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
-#ifndef _XWIN_H
+#ifndef XWIN_H
 
-#define _XWIN_H 1
+#define XWIN_H 1
 
 #define NBUTS 3
 
 #include "map.h"
 #include "occupy.h"
+#include "xinit.h"
 
 enum button_class {
   ATT, DEF, GUE
 };
 
-extern void update_buttons (const int);
-extern void update_cross_win (int);
-extern void draw_map (int, int, int, int);
-extern void draw_effects (Action);
-extern Coord win_pos2map_coord (int, int);
+extern void update_buttons (struct x_info_struct *, const int, char *);
+extern void draw_turn_win (struct x_info_struct *);
+extern void draw_map (struct x_info_struct *, int, int, int, int);
+extern void draw_effects (struct x_info_struct *, Action);
+extern Coord win_pos2map_coord (struct x_info_struct *, int, int);
+extern void create_end_win (struct x_info_struct *);
+extern void draw_end_win (struct x_info_struct *);
 
 #endif /* xwin.h  */
